pub struct DroppedItem {
pub slot: Slot,
}Expand description
A dropped item on the ground.
Entities with this component represent items that can be picked up
by players. Combined with Position, Velocity, BoundingBox,
and Lifetime to create a full dropped item entity.
Fields
slot: SlotThe item stack (ID, count, component data).