PickupDelay

Struct PickupDelay 

pub struct PickupDelay {
    pub remaining_ticks: u32,
}
Pickup delay before a dropped item can be collected.

Decremented each tick. While remaining > 0, the item cannot be picked up by any player. Default: 10 ticks (0.5s) for block drops.

Fields

remaining_ticks: u32

Remaining ticks before the item is pickable.