pub struct Sneaking;Expand description
Marker component for sneaking state.
Added when a player starts sneaking, removed when they stop. Used by the block interaction system to determine whether right-click should interact with the clicked block or place a block instead.