ChatContext

Trait ChatContext 

pub trait ChatContext {
    // Required methods
    fn send(&self, text: &str);
    fn send_component(&self, component: &TextComponent);
    fn action_bar(&self, text: &str);
    fn broadcast(&self, text: &str);
    fn broadcast_component(&self, component: &TextComponent);
}
Chat and messaging.

Required Methods

fn send(&self, text: &str)

Sends a plain text message to the current player.

fn send_component(&self, component: &TextComponent)

Sends a styled message to the current player.

fn action_bar(&self, text: &str)

Sends an action bar message to the current player.

fn broadcast(&self, text: &str)

Broadcasts a plain text message to ALL connected players.

fn broadcast_component(&self, component: &TextComponent)

Broadcasts a styled message to ALL connected players.

Implementors