pub struct BlockBrokenEvent {
pub position: BlockPosition,
pub block_state: u16,
pub sequence: i32,
pub cancelled: bool,
}Expand description
A player broke a block.
Fired when the server receives a BlockDig packet with status 0.
The breaking player is available via ctx.player().
Fields
position: BlockPositionPosition of the broken block.
block_state: u16Block state that was at this position before breaking.
sequence: i32Sequence number for client acknowledgement.
cancelled: boolWhether this event has been cancelled by a Validate handler.