Structs
- Command
Builder - Fluent builder for registering a command with typed arguments.
- Command
Entry - A registered command entry.
- Plugin
Metadata - Identity metadata for a plugin.
- Plugin
Registrar - Plugin registration interface for events, commands, and systems.
- Plugin
System Builder - Fluent builder for registering a system via a plugin.
- Variant
Builder - Builder for a single variant of a polymorphic command.
Traits
- Plugin
- A server plugin that registers event handlers and lifecycle hooks.
Type Aliases
- Command
Handler - Handler function type for commands with typed arguments.