Module handle

Module handle 

Long-lived handle to the recipe registry.

RecipeRegistryHandle abstracts the mutable recipe registry so that RecipeRegistrar and PluginRegistrar reference a trait object instead of a concrete registry type. The concrete implementation lives in basalt-recipes.

Traits

RecipeRegistryHandle
Long-lived handle to the recipe registry runtime.