Container types shared across the Basalt crate ecosystem.
The main type is Container, a reusable template value describing
how to open a container window. Use ContainerBuilder (or
Container::builder()) for fluent construction.
Structs
- Container
- Reusable template value describing how to open a container window.
- Container
Builder - Fluent builder for
Containerconfigurations.
Enums
- Container
Backing - How a container window is backed in the world.
- Inventory
Type - Type of inventory window in Minecraft 1.21.4.